@@ -1,30 +1,42 @@
+"""
+LRUCache module for Decorators
+"""
+
 import functools
 from lru.lrucache import LRUCache
 from datetime import datetime, timedelta
+from typing import Any
 
-def lru_cache(capacity: int=128, **kwargs) -> int:
-    """Decorators for LRUCache classes. Given the
-    capacity of cache based on LRUCache classes, for example:
-    
-    ```
-    @lru_cache(capacity=3)
-    def foo(x):
-        pass
+
+def lru_cache(capacity: int = 128, **kwargs) -> Any:
     """
-    def wrapper(func):
+    Decorators for LRUCache classes. Given the
+    capacity of cache based on LRUCache classes
+
+    Example: ::
+
+        @lru_cache(capacity=3)
+        def foo(x):
+            pass
+
+    """
+    def wrapper():
         return LRUCache(capacity=capacity, **kwargs)
     return wrapper
 
-def lru_cache_time(capacity: int=128, seconds: int=60*15, **kwargs) -> int:
-    """Decorators for LRUCache classes using
-    expired cached time. This is an mock only,
-    probably not ready to bump into major version. for example:
 
-    ```
-    @lru_cache_time(capacity=3, seconds=60)
-    def foo(x):
-        pass
-    ```
+def lru_cache_time(capacity: int = 128, seconds: int = 60*15, **kwargs) -> object:
+    """
+    Decorators for LRUCache classes using
+    expired cached time. This is an mock only,
+    probably not ready to bump into major version
+
+    Example: ::
+
+        @lru_cache_time(capacity=3, seconds=60)
+        def foo(x):
+            pass
+
     """
     def wrapper(func):
         update_time = timedelta(seconds=seconds)
@@ -43,4 +55,4 @@ def lru_cache_time(capacity: int=128, seconds: int=60*15, **kwargs) -> int:
                 next_update_time = now_time + update_time
             return func(*args, **kwargs)
         return wrapped
-    return wrapper
\ No newline at end of file
+    return wrapper
