@@ -1,37 +1,32 @@
 import time
 import threading
-import weakref
 import json
 import hashlib
-from lru.heap import Heap
-from lru.utils import BypassThreadSafe
-from abc import ABC, abstractmethod, ABCMeta
+from .heap import Heap
+from .utils import BypassThreadSafe
+from abc import abstractmethod, ABCMeta
+from typing import Union
+
 
 class BoundedLRUCache:
-
     __metaclass__ = ABCMeta
 
     @abstractmethod
     def clear_all(self):
-        """Remove all element in cache dict."""
+        """
+        Remove all element in cache dict.
+        """
+
 
 class LRUCache(BoundedLRUCache):
+    """
+    Initial class for representing LRUCache, given the several parameter such as :
 
-    def __init__(self, capacity: int=128, seconds: int=60*15, thread_safe: bool=False):
-        """Constructor for LRU Cache objects. Given
-        the several parameter such as:
-
-        :capacity: param for set the cache capacity, maximum
-        number is 128
-
-        :seconds: param for set the duration for store the cache,
-        maximum is 15 minutes
-
-        :dict: param for set the key and value into dict type
-
-        :thread_safe: param for enable/disable thread safe option,
-        default is False
-        """
+    :param capacity: param for set the cache capacity, maximum number is 128
+    :param seconds: param for set the duration for store the cache, maximum is 15 minutes
+    :param thread_safe: param for enable/disable thread safe option, default is False
+    """
+    def __init__(self, capacity: int = 128, seconds: int = 60 * 15, thread_safe: bool = False):
         self.capacity = capacity
         self.seconds = seconds
         self._cache_dict = {}
@@ -48,7 +43,7 @@ class LRUCache(BoundedLRUCache):
 
         if not isinstance(seconds, int):
             raise ValueError("Expected to set the duration of cache in seconds time.")
-        elif seconds > 60*15:
+        elif seconds > 60 * 15:
             raise ValueError("Maximum duration of cache is 15 minutes.")
         elif seconds < 0:
             raise ValueError("Cache duration can't set below zero time.")
@@ -56,7 +51,11 @@ class LRUCache(BoundedLRUCache):
     def __call__(self, *args, **kwargs):
         return self.cache
 
+    @property
     def __len__(self):
+        """
+        property for get length of the cache capacity
+        """
         return len(self.capacity)
 
     def __str__(self):
@@ -69,30 +68,44 @@ class LRUCache(BoundedLRUCache):
     def __hash__(self, key: int):
         # should hashing a key
         # not an Dict object
-        print("The hash for dict object is: ") # pragma: no cover
+        # possible bug, WIP: fix this hash method
+        print("The hash for dict object is: ")  # pragma: no cover
         return hashlib.md5(json.dumps(self.get_cache(key)))
 
     @property
     def ttl(self):
-        """property for getting ttl in seconds."""
+        """
+        property for get TTL (time-to-live) in seconds.
+        """
         return self.seconds
 
     def is_empty(self):
+        """
+        Check whether the cache element is empty or not,
+        return `True` if is empty otherwise will
+        return `False` if is not empty
+        """
         if len(self._cache_dict) == 0:
             return True
         return False
 
     def clear_all(self):
+        """
+        Clear all cache in element
+        """
         return self._cache_dict.clear()
 
-    def clear_cache_key(self, key: int) -> int:
-        """Clear cache in element based on their key."""
+    def clear_cache_key(self, key: int) -> None:
+        """
+        Clear cache in element based on their key.
+        """
         with self.lock:
             if self.get_cache(key):
                 return self._cache_dict.clear()
 
-    def get_duration(self, expired_time: int=3600) -> int:
-        """Get duration of cache, return `True` if the duration
+    def get_duration(self, expired_time: int = 3600) -> int:
+        """
+        Get duration of cache, return `True` if the duration
         is exceed for expired time otherwise return `False`
         when the duration is even or below the expired time.
         """
@@ -100,8 +113,9 @@ class LRUCache(BoundedLRUCache):
             return True
         return False
 
-    def get_ttl(self, key: int) -> int:
-        """Get time-to-live an objects based on their
+    def get_ttl(self, key: int) -> Union[int, bool, None]:
+        """
+        Get time-to-live an objects based on their
         cache keys. Return False if the objects hasn't a key
         or time-to-live is expired.
         """
@@ -112,8 +126,9 @@ class LRUCache(BoundedLRUCache):
                 return ttl
         return None
 
-    def get_cache(self, key: int):
-        """Get cache in element based on their key, return
+    def get_cache(self, key: int) -> int:
+        """
+        Get cache in element based on their key, return
         `True` if the element has a key, otherwise return `False`
         when element hasn't a key.
         """
@@ -123,7 +138,8 @@ class LRUCache(BoundedLRUCache):
             return False
 
     def get_capacity(self):
-        """Get cache capacity, return `True` if the cache
+        """
+        Get cache capacity, return `True` if the cache
         is full otherwiser return `False` when the cache
         is not full.
         """
@@ -131,16 +147,16 @@ class LRUCache(BoundedLRUCache):
             return True
         return False
 
-    def set(self, key: int, value: int) -> int:
-        """Set an objects that wants to be cached.
-
-        :key: given key parameter as an integer
-
-        :value: given value parameter of that key as an integer
+    def set(self, key: int, value: str) -> dict:
         """
-        end = time.perf_counter()
-        start = time.perf_counter()
-        access_time = start - end
+        Set an objects that wants to be cached
+
+        :param key: given key parameter as an integer
+        :param value: given value parameter of that key as an string
+        """
+        end: float = time.perf_counter()
+        start: float = time.perf_counter()
+        access_time: float = start - end
 
         if self.get_cache(key):
             # update method is not working
@@ -151,36 +167,41 @@ class LRUCache(BoundedLRUCache):
             return self._cache_dict
 
         if self.get_capacity():
-            minimum = self.cache.remove()[0] # pragma: no cover
+            minimum = self.cache.remove()[0]  # pragma: no cover
             del self._cache_dict[minimum]
 
         self.cache.add(key, access_time)
         self._cache_dict[key] = (value, access_time)
         return self._cache_dict
 
-    def get(self, key: int):
-        """Get the objects based on their key in cache element
-
-        :key: given key parameter as an integer
+    def get(self, key: int) -> int:
         """
-        if not self.get_cache(key): # pragma: no cover
+        Get the objects based on their key in cache element
+
+        :param key: given key parameter as an integer
+        """
+        if not self.get_cache(key):  # pragma: no cover
             raise KeyError("Cache key not in elements.")
-        
+
         if not self.is_empty:
             raise KeyError("Nor between cache key and cache is empty.")
 
-        access_time = time.perf_counter()
+        access_time: float = time.perf_counter()
         self.cache.update(key, access_time)
         value = self._cache_dict[key][0]
         self._cache_dict[key] = (value, access_time)
         return value
 
     def get_lru_element(self):
-        """Returned a dict type based on their key in cache element."""
-        with self.lock: # pragma: no cover
+        """
+        Returned a dict type based on their key in cache element.
+        """
+        with self.lock:  # pragma: no cover
             key = self.cache.heap[0][0]
             return self._cache_dict[key]
 
     def get_dict(self):
-        """Returned a dict type in cache element."""
+        """
+        Returned a dict type in cache element.
+        """
         return self._cache_dict
