@@ -1,12 +1,13 @@
-"""Utils module for bypass thread safe in LRU."""
+"""
+LRUCache module for bypass thread safe in LRU.
+"""
 
-from collections import namedtuple
 
 class BypassThreadSafe:
-    """Classes for bypassing thread safe
+    """
+    Classes for bypassing thread safe
     in LRU Cache class.
     """
-
     def __enter__(self):
         pass
 
